---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2016-08-19;175
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20160908&codiceRedaz=16G00188&dataVigenza=20251104
dataGU: 20160908
codiceRedaz: 16G00188
dataVigenza: 20251104
---

# Testo unico in materia di societa' a partecipazione pubblica. (16G00188)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76 e 87 della Costituzione;

Visto l'articolo 18 della legge 7 agosto 2015, n. 124, recante deleghe al Governo in materia di riorganizzazione delle amministrazioni pubbliche;

Vista la legge 7 agosto 1990, n. 241;

Visto il decreto legislativo 18 agosto 2000, n. 267;

Visto il decreto legislativo 30 marzo 2001, n. 165, recante norme generali sull'ordinamento del lavoro alle dipendenze delle amministrazioni pubbliche;

Visto il decreto legislativo 14 marzo 2013, n. 33, recante «Riordino della disciplina riguardante il diritto di accesso civico e gli obblighi di pubblicita', trasparenza e diffusione di informazioni da parte delle pubbliche amministrazioni»;

Visto il decreto legislativo 18 aprile 2016, n. 50, recante «Attuazione delle direttive 2014/23/UE, 2014/24/UE e 2014/25/UE sull'aggiudicazione dei contratti di concessione, sugli appalti pubblici e sulle procedure d'appalto degli enti erogatori nei settori dell'acqua, dell'energia, dei trasporti e dei servizi postali, nonche' per il riordino della disciplina vigente in materia di contratti pubblici relativi a lavori, servizi e forniture»;

Vista la preliminare deliberazione del Consiglio dei ministri, adottata nella riunione del 20 gennaio 2016;

Acquisito il parere della Conferenza unificata, ai sensi dell'articolo 8, del decreto legislativo 28 agosto 1997, n. 281, espresso nella riunione del 14 aprile 2016;

Udito il parere del Consiglio di Stato, espresso dalla Sezione consultiva per gli atti normativi nell'adunanza del 16 marzo 2016;

Acquisito il parere della Commissione parlamentare per la semplificazione e delle Commissioni parlamentari competenti per materia e per i profili finanziari;

Vista la preliminare deliberazione del Consiglio dei ministri, adottata nella riunione del 14 luglio 2016;

Acquisiti i pareri definitivi delle competenti Commissioni parlamentari ai sensi dell'articolo 16, comma 4, della citata legge n. 124 del 2015;

Vista la deliberazione del Consiglio dei ministri, adottata nella riunione del 10 agosto 2016;

Acquisita l'intesa in sede di Conferenza Unificata, di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, raggiunta nella seduta del 16 marzo 2017;

Sulla proposta del Ministro per la semplificazione e la pubblica amministrazione, di concerto con il Ministro dell'economia e delle finanze;

Emana il seguente decreto legislativo:

## Art. 1. - Oggetto

1. Le disposizioni del presente decreto hanno a oggetto la costituzione di societa' da parte di amministrazioni pubbliche, nonche' l'acquisto, il mantenimento e la gestione di partecipazioni da parte di tali amministrazioni, in societa' a totale o parziale partecipazione pubblica, diretta o indiretta.

2. Le disposizioni contenute nel presente decreto sono applicate avendo riguardo all'efficiente gestione delle partecipazioni pubbliche, alla tutela e promozione della concorrenza e del mercato, nonche' alla razionalizzazione e riduzione della spesa pubblica.

3. Per tutto quanto non derogato dalle disposizioni del presente decreto, si applicano alle societa' a partecipazione pubblica le norme sulle societa' contenute nel codice civile e le norme generali di diritto privato.

4. Restano ferme:

- a) le specifiche disposizioni, contenute in leggi o regolamenti governativi o ministeriali, che disciplinano societa' a partecipazione pubblica di diritto singolare costituite per l'esercizio della gestione di servizi di interesse generale o di interesse economico generale o per il perseguimento di una specifica missione di pubblico interesse;
- b) le disposizioni di legge riguardanti la partecipazione di amministrazioni pubbliche a enti associativi diversi dalle societa' e a fondazioni.

5. Le disposizioni del presente decreto si applicano, solo se espressamente previsto, alle societa' quotate, come definite dall'articolo 2, comma 1, lettera p), nonche' alle societa' da esse ((controllate)).

## Art. 2. - Definizioni

1. Ai fini del presente decreto si intendono per:

- a) «amministrazioni pubbliche»: le amministrazioni di cui all'articolo 1, comma 2, del decreto legislativo n. 165 del 2001, i loro consorzi o associazioni per qualsiasi fine istituiti, gli enti pubblici economici e le autorita' di sistema portuale;
- b) «controllo»: la situazione descritta nell'articolo 2359 del codice civile. Il controllo puo' sussistere anche quando, in applicazione di norme di legge o statutarie o di patti parasociali, per le decisioni finanziarie e gestionali strategiche relative all'attivita' sociale e' richiesto il consenso unanime di tutte le parti che condividono il controllo;
- c) «controllo analogo»: la situazione in cui l'amministrazione esercita su una societa' un controllo analogo a quello esercitato sui propri servizi, esercitando un'influenza determinante sia sugli obiettivi strategici che sulle decisioni significative della societa' controllata. Tale controllo puo' anche essere esercitato da una persona giuridica diversa, a sua volta controllata allo stesso modo dall'amministrazione partecipante;
- d) «controllo analogo congiunto»: la situazione in cui l'amministrazione esercita congiuntamente con altre amministrazioni su una societa' un controllo analogo a quello esercitato sui propri servizi. La suddetta situazione si verifica al ricorrere delle condizioni di cui all'articolo 5, comma 5, del decreto legislativo 18 aprile 2016, n. 50;
- e) «enti locali»: gli enti di cui all'articolo 2 del decreto legislativo 18 agosto 2000, n. 267;
- f) «partecipazione»: la titolarita' di rapporti comportanti la qualita' di socio in societa' o la titolarita' di strumenti finanziari che attribuiscono diritti amministrativi;
- g) «partecipazione indiretta»: la partecipazione in una societa' detenuta da un'amministrazione pubblica per il tramite di societa' o altri organismi soggetti a controllo da parte della medesima amministrazione pubblica;
- h) «servizi di interesse generale»: le attivita' di produzione e fornitura di beni o servizi che non sarebbero svolte dal mercato senza un intervento pubblico o sarebbero svolte a condizioni differenti in termini di accessibilita' fisica ed economica, continuita', non discriminazione, qualita' e sicurezza, che le amministrazioni pubbliche, nell'ambito delle rispettive competenze, assumono come necessarie per assicurare la soddisfazione dei bisogni della collettivita' di riferimento, cosi' da garantire l'omogeneita' dello sviluppo e la coesione sociale, ivi inclusi i servizi di interesse economico generale;
- i) «servizi di interesse economico generale»: i servizi di interesse generale erogati o suscettibili di essere erogati dietro corrispettivo economico su un mercato;
- l) "societa'": gli organismi di cui ai titoli V e VI, capo I, del libro V del codice civile, anche aventi come oggetto sociale lo svolgimento di attivita' consortili, ai sensi dell'articolo 2615-ter del codice civile;
- m) «societa' a controllo pubblico»: le societa' in cui una o piu' amministrazioni pubbliche esercitano poteri di controllo ai sensi della lettera b);
- n) «societa' a partecipazione pubblica»: le societa' a controllo pubblico, nonche' le altre societa' partecipate direttamente da amministrazioni pubbliche o da societa' a controllo pubblico;
- o) «societa' in house»: le societa' sulle quali un'amministrazione esercita il controllo analogo o piu' amministrazioni esercitano il controllo analogo congiunto, nelle quali la partecipazione di capitali privati avviene nelle forme di cui all'articolo 16, comma 1, e che soddisfano il requisito dell'attivita' prevalente di cui all'articolo 16, comma 3;
- p) «societa' quotate»: le societa' a partecipazione pubblica che emettono azioni quotate in mercati regolamentati; le societa' che hanno emesso, alla data del 31 dicembre 2015, strumenti finanziari, diversi dalle azioni, quotati in mercati regolamentati. ((11))

--------------- AGGIORNAMENTO (11) Il D.L. 17 maggio 2022, n. 50, convertito con modificazioni dalla L. 15 luglio 2022, n. 91, ha disposto (con l'art. 52, comma 1-bis) che "Il termine di cui all'articolo 2, comma 1, lettera p), del testo unico in materia di societa' a partecipazione pubblica, di cui al decreto legislativo 19 agosto 2016, n. 175, e' fissato, per le societa' del comparto energetico, al 31 dicembre 2021".

## Art. 3.

Tipi di societa' in cui e' ammessa la partecipazione pubblica

1. Le amministrazioni pubbliche possono partecipare esclusivamente a societa', anche consortili, costituite in forma di societa' per azioni o di societa' a responsabilita' limitata, anche in forma cooperativa.

2. Nelle societa' a responsabilita' limitata a controllo pubblico l'atto costitutivo o lo statuto in ogni caso prevede la nomina dell'organo di controllo o di un revisore. Nelle societa' per azioni a controllo pubblico la revisione legale dei conti non puo' essere affidata al collegio sindacale.

## Art. 4.

Finalita' perseguibili mediante l'acquisizione e la gestione di partecipazioni pubbliche

1. Le amministrazioni pubbliche non possono, direttamente o indirettamente, costituire societa' aventi per oggetto attivita' di produzione di beni e servizi non strettamente necessarie per il perseguimento delle proprie finalita' istituzionali, ne' acquisire o mantenere partecipazioni, anche di minoranza, in tali societa'.

2. Nei limiti di cui al comma 1, le amministrazioni pubbliche possono, direttamente o indirettamente, costituire societa' e acquisire o mantenere partecipazioni in societa' esclusivamente per lo svolgimento delle attivita' sotto indicate:

- a) produzione di un servizio di interesse generale, ivi inclusa la realizzazione e la gestione delle reti e degli impianti funzionali ai servizi medesimi;
- b) progettazione e realizzazione di un'opera pubblica sulla base di un accordo di programma fra amministrazioni pubbliche, ai sensi dell'articolo 193 del decreto legislativo n. 50 del 2016;
- c) realizzazione e gestione di un'opera pubblica ovvero organizzazione e gestione di un servizio d'interesse generale attraverso un contratto di partenariato di cui all'articolo 180 del decreto legislativo n. 50 del 2016, con un imprenditore selezionato con le modalita' di cui all'articolo 17, commi 1 e 2;
- d) autoproduzione di beni o servizi strumentali all'ente o agli enti pubblici partecipanti o allo svolgimento delle loro funzioni, nel rispetto delle condizioni stabilite dalle direttive europee in materia di contratti pubblici e della relativa disciplina nazionale di recepimento;
- e) servizi di committenza, ivi incluse le attivita' di committenza ausiliarie, apprestati a supporto di enti senza scopo di lucro e di amministrazioni aggiudicatrici di cui all'articolo 3, comma 1, lettera a), del decreto legislativo n. 50 del 2016.

3. Al solo fine di ottimizzare e valorizzare l'utilizzo di beni immobili facenti parte del proprio patrimonio, le amministrazioni pubbliche possono, altresi', anche in deroga al comma 1, acquisire partecipazioni in societa' aventi per oggetto sociale esclusivo la valorizzazione del patrimonio delle amministrazioni stesse, tramite il conferimento di beni immobili allo scopo di realizzare un investimento secondo criteri propri di un qualsiasi operatore di mercato.

4. Le societa' in house hanno come oggetto sociale esclusivo una o piu' delle attivita' di cui alle lettere a), b), d) ed e) del comma 2. Salvo quanto previsto dall'articolo 16, tali societa' operano in via prevalente con gli enti costituenti o partecipanti o affidanti.

5. Fatte salve le diverse previsioni di legge regionali adottate nell'esercizio della potesta' legislativa in materia di organizzazione amministrativa, e' fatto divieto alle societa' di cui al comma 2, lettera d), controllate da enti locali, di costituire nuove societa' e di acquisire nuove partecipazioni in societa'. Il divieto non si applica alle societa' che hanno come oggetto sociale esclusivo la gestione delle partecipazioni societarie di enti locali, salvo il rispetto degli obblighi previsti in materia di trasparenza dei dati finanziari e di consolidamento del bilancio degli enti partecipanti.

6. E' fatta salva la possibilita' di costituire societa' o enti in attuazione dell'articolo 34 del regolamento (CE) n. 1303/2013 del Parlamento europeo e del Consiglio del 17 dicembre 2013, dell'articolo 42 del regolamento (UE) n. 1305/2013 del Parlamento europeo e del Consiglio, del 17 dicembre 2013, e dell'articolo 61 del regolamento (CE) n. 508 del 2014 del Parlamento europeo e del Consiglio 15 maggio 2014.

7. Sono altresi' ammesse le partecipazioni, dirette e indirette, nelle societa' aventi per oggetto sociale prevalente la gestione di spazi fieristici e l'organizzazione di eventi fieristici e, nel rispetto dei principi di concorrenza e apertura al mercato, le attivita', le forniture e i servizi direttamente connessi e funzionali ai visitatori e agli espositori, la realizzazione e la gestione di impianti di trasporto a fune per la mobilita' turistico-sportiva eserciti in aree montane, nonche' la produzione di energia da fonti rinnovabili. (15)

8. E' fatta salva la possibilita' di costituire, ai sensi degli articoli 2 e 3 del decreto legislativo 27 luglio 1999, n. 297, le societa' con caratteristiche di spin off o di start up universitari previste dall'articolo 6, comma 9, della legge 30 dicembre 2010, n. 240, nonche' quelle con caratteristiche analoghe degli enti di ricerca. E' inoltre fatta salva la possibilita', per le universita', di costituire societa' per la gestione di aziende agricole con funzioni didattiche.

9. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze o dell'organo di vertice dell'amministrazione partecipante, motivato con riferimento alla misura e qualita' della partecipazione pubblica, agli interessi pubblici a essa connessi e al tipo di attivita' svolta, riconducibile alle finalita' di cui al comma 1, anche al fine di agevolarne la quotazione ai sensi dell'articolo 18, puo' essere deliberata l'esclusione totale o parziale dell'applicazione delle disposizioni del presente articolo a singole societa' a partecipazione pubblica. Il decreto e' trasmesso alle Camere ai fini della comunicazione alle commissioni parlamentari competenti. I Presidenti di Regione e delle province autonome di Trento e Bolzano, con provvedimento adottato ai sensi della legislazione regionale e nel rispetto dei principi di trasparenza e pubblicita', possono, nell'ambito delle rispettive competenze, deliberare l'esclusione totale o parziale dell'applicazione delle disposizioni del presente articolo a singole societa' a partecipazione della Regione o delle province autonome di Trento e Bolzano, motivata con riferimento alla misura e qualita' della partecipazione pubblica, agli interessi pubblici a essa connessi e al tipo di attivita' svolta, riconducibile alle finalita' di cui al comma 1. Il predetto provvedimento e' trasmesso alla competente Sezione regionale di controllo della Corte dei conti, alla struttura di cui all'articolo 15, comma 1, nonche' alle Camere ai fini della comunicazione alle commissioni parlamentari competenti.

9-bis. Nel rispetto della disciplina europea, e' fatta salva la possibilita' per le amministrazioni pubbliche di acquisire o mantenere partecipazioni in societa' che producono servizi economici di interesse generale a rete, di cui all'articolo 3-bis del decreto-legge 13 agosto 2011, n. 138, convertito, con modificazioni, dalla legge 14 settembre 2011, n. 148, anche fuori dall'ambito territoriale della collettivita' di riferimento, in deroga alle previsioni di cui al comma 2, lettera a), purche' l'affidamento dei servizi, in corso e nuovi, sia avvenuto e avvenga tramite procedure ad evidenza pubblica. Per tali partecipazioni, trova piena applicazione l'articolo 20, comma 2, lettera e). Resta fermo quanto previsto dall'articolo 16.

9-ter. E' fatta salva la possibilita' per le amministrazioni pubbliche di acquisire o mantenere partecipazioni, comunque non superiori all'1 per cento del capitale sociale, in societa' bancarie di finanza etica e sostenibile, come definite dall'articolo 111-bis del testo unico delle leggi in materia bancaria e creditizia, di cui al decreto legislativo 1° settembre 1993, n. 385, senza ulteriori oneri finanziari rispetto a quelli derivanti dalla partecipazione medesima.

9-quater. Le disposizioni del presente articolo non si applicano alla costituzione ne' all'acquisizione o al mantenimento di partecipazioni, da parte delle amministrazioni pubbliche, in societa' aventi per oggetto sociale prevalente la produzione, il trattamento, la lavorazione e l'immissione in commercio del latte, comunque trattato, ((, dei prodotti lattiero-caseari e dei prodotti ortofrutticoli)).

-------------- AGGIORNAMENTO (15) La L. 30 dicembre 2023, n. 214 ha disposto (con l'art. 19, comma 2) che "Entro centoventi giorni dalla data di entrata in vigore della presente legge, il Ministro delle imprese e del made in Italy, previa consultazione delle associazioni di categoria maggiormente rappresentative a livello nazionale, adotta linee guida con le quali sono definite le modalita' che il gestore dello spazio fieristico osserva per garantire condizioni di accesso eque e non discriminatorie e una corretta e completa informazione alle imprese terze che operano nel mercato fieristico. L'efficacia delle disposizioni di cui al comma 1 decorre dalla pubblicazione dell'avviso dell'avvenuta adozione delle linee guida nella Gazzetta Ufficiale".

## Art. 4-bis. - (( (Disposizioni speciali per lo svolgimento di attivita' di ricerca nell'ambito del Piano nazionale di ripresa e resilienza). ))

## Art. 5. - Oneri di motivazione analitica

1. A eccezione dei casi in cui la costituzione di una societa' o l'acquisto di una partecipazione, anche attraverso aumento di capitale, avvenga in conformita' a espresse previsioni legislative, l'atto deliberativo di costituzione di una societa' a partecipazione pubblica, anche nei casi di cui all'articolo 17, o di acquisto di partecipazioni, anche indirette, da parte di amministrazioni pubbliche in societa' gia' costituite deve essere analiticamente motivato con riferimento alla necessita' della societa' per il perseguimento delle finalita' istituzionali di cui all'articolo 4, evidenziando, altresi', le ragioni e le finalita' che giustificano tale scelta, anche sul piano della convenienza economica e della sostenibilita' finanziaria, nonche' di gestione diretta o esternalizzata del servizio affidato. La motivazione deve anche dare conto della compatibilita' della scelta con i principi di efficienza, di efficacia e di economicita' dell'azione amministrativa.

2. L'atto deliberativo di cui al comma 1 da' atto della compatibilita' dell'intervento finanziario previsto con le norme dei trattati europei e, in particolare, con la disciplina europea in materia di aiuti di Stato alle imprese. Gli enti locali sottopongono lo schema di atto deliberativo a forme di consultazione pubblica, secondo modalita' da essi stessi disciplinate.

3. L'amministrazione invia l'atto deliberativo di costituzione della societa' o di acquisizione della partecipazione diretta o indiretta ((...)) all'Autorita' garante della concorrenza e del mercato, che puo' esercitare i poteri di cui all'articolo 21-bis della legge 10 ottobre 1990, n. 287 ((, e alla Corte dei conti, che delibera, entro il termine di sessanta giorni dal ricevimento, in ordine alla conformita' dell'atto a quanto disposto dai commi 1 e 2 del presente articolo, nonche' dagli articoli 4, 7 e 8, con particolare riguardo alla sostenibilita' finanziaria e alla compatibilita' della scelta con i principi di efficienza, di efficacia e di economicita' dell'azione amministrativa. Qualora la Corte non si pronunci entro il termine di cui al primo periodo, l'amministrazione puo' procedere alla costituzione della societa' o all'acquisto della partecipazione di cui al presente articolo)).

4. Ai fini di quanto previsto dal comma 3, per gli atti delle amministrazioni dello Stato e degli enti nazionali sono competenti le Sezioni Riunite in sede di controllo; per gli atti delle regioni e degli enti locali, nonche' dei loro enti strumentali, delle universita' o delle altre istituzioni pubbliche di autonomia aventi sede nella regione, e' competente la Sezione regionale di controllo; per gli atti degli enti assoggettati a controllo della Corte dei conti ai sensi della legge 21 marzo 1958, n. 259, e' competente la Sezione del controllo sugli enti medesimi. ((La segreteria della Sezione competente trasmette il parere, entro cinque giorni dal deposito, all'amministrazione pubblica interessata, la quale e' tenuta a pubblicarlo entro cinque giorni dalla ricezione nel proprio sito internet istituzionale. In caso di parere in tutto o in parte negativo, ove l'amministrazione pubblica interessata intenda procedere egualmente e' tenuta a motivare analiticamente le ragioni per le quali intenda discostarsi dal parere e a dare pubblicita', nel proprio sito internet istituzionale, a tali ragioni)).

## Art. 6.

Principi fondamentali sull'organizzazione e sulla gestione delle societa' a controllo pubblico

1. Le societa' a controllo pubblico, che svolgano attivita' economiche protette da diritti speciali o esclusivi, insieme con altre attivita' svolte in regime di economia di mercato, in deroga all'obbligo di separazione societaria previsto dal comma 2-bis dell'articolo 8 della legge 10 ottobre 1990, n. 287, adottano sistemi di contabilita' separata per le attivita' oggetto di diritti speciali o esclusivi e per ciascuna attivita'.

2. Le societa' a controllo pubblico predispongono specifici programmi di valutazione del rischio di crisi aziendale e ne informano l'assemblea nell'ambito della relazione di cui al comma 4.

3. Fatte salve le funzioni degli organi di controllo previsti a norma di legge e di statuto, le societa' a controllo pubblico valutano l'opportunita' di integrare, in considerazione delle dimensioni e delle caratteristiche organizzative nonche' dell'attivita' svolta, gli strumenti di governo societario con i seguenti:

- a) regolamenti interni volti a garantire la conformita' dell'attivita' della societa' alle norme di tutela della concorrenza, comprese quelle in materia di concorrenza sleale, nonche' alle norme di tutela della proprieta' industriale o intellettuale;
- b) un ufficio di controllo interno strutturato secondo criteri di adeguatezza rispetto alla dimensione e alla complessita' dell'impresa sociale, che collabora con l'organo di controllo statutario, riscontrando tempestivamente le richieste da questo provenienti, e trasmette periodicamente all'organo di controllo statutario relazioni sulla regolarita' e l'efficienza della gestione;
- c) codici di condotta propri, o adesione a codici di condotta collettivi aventi a oggetto la disciplina dei comportamenti imprenditoriali nei confronti di consumatori, utenti, dipendenti e collaboratori, nonche' altri portatori di legittimi interessi coinvolti nell'attivita' della societa';
- d) programmi di responsabilita' sociale d'impresa, in conformita' alle raccomandazioni della Commissione dell'Unione europea.

4. Gli strumenti eventualmente adottati ai sensi del comma 3 sono indicati nella relazione sul governo societario che le societa' controllate predispongono annualmente, a chiusura dell'esercizio sociale e pubblicano contestualmente al bilancio d'esercizio.

5. Qualora le societa' a controllo pubblico non integrino gli strumenti di governo societario con quelli di cui al comma 3, danno conto delle ragioni all'interno della relazione di cui al comma 4.

## Art. 7.

Costituzione di societa' a partecipazione pubblica

1. La deliberazione di partecipazione di un'amministrazione pubblica alla costituzione di una societa' e' adottata con:

- a) decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze di concerto con i ministri competenti per materia, previa deliberazione del Consiglio dei ministri, in caso di partecipazioni statali;
- b) provvedimento del competente organo della regione, in caso di partecipazioni regionali;
- c) deliberazione del consiglio comunale, in caso di partecipazioni comunali;
- d) delibera dell'organo amministrativo dell'ente, in tutti gli altri casi di partecipazioni pubbliche.

2. L'atto deliberativo e' redatto in conformita' a quanto previsto all'articolo 5, comma 1.

3. L'atto deliberativo contiene altresi' l'indicazione degli elementi essenziali dell'atto costitutivo, come previsti dagli articoli 2328 e 2463 del codice civile, rispettivamente per le societa' per azioni e per le societa' a responsabilita' limitata.

4. L'atto deliberativo e' pubblicato sui siti istituzionali dell'amministrazione pubblica partecipante.

5. Nel caso in cui sia prevista la partecipazione all'atto costitutivo di soci privati, la scelta di questi ultimi avviene con procedure di evidenza pubblica a norma dell'articolo 5, comma 9, del decreto legislativo n. 50 del 2016.

6. Nel caso in cui una societa' a partecipazione pubblica sia costituita senza l'atto deliberativo di una o piu' amministrazioni pubbliche partecipanti, o l'atto deliberativo di partecipazione di una o piu' amministrazioni sia dichiarato nullo o annullato, le partecipazioni sono liquidate secondo quanto disposto dall'articolo 24, comma 5. Se la mancanza o invalidita' dell'atto deliberativo riguarda una partecipazione essenziale ai fini del conseguimento dell'oggetto sociale, si applicano le disposizioni di cui all'articolo 2332 del codice civile.

7. Sono, altresi', adottati con le modalita' di cui ai commi 1 e 2:

- a) le modifiche di clausole dell'oggetto sociale che consentano un cambiamento significativo dell'attivita' della societa';
- b) la trasformazione della societa';
- c) il trasferimento della sede sociale all'estero;
- d) la revoca dello stato di liquidazione.

## Art. 8.

Acquisto di partecipazioni in societa' gia' costituite

1. Le operazioni, anche mediante sottoscrizione di un aumento di capitale o partecipazione a operazioni straordinarie, che comportino l'acquisto da parte di un'amministrazione pubblica di partecipazioni in societa' gia' esistenti sono deliberate secondo le modalita' di cui all'articolo 7, commi 1 e 2.

2. L'eventuale mancanza o invalidita' dell'atto deliberativo avente ad oggetto l'acquisto della partecipazione rende inefficace il contratto di acquisto della partecipazione medesima.

3. Le disposizioni del presente articolo si applicano anche all'acquisto, da parte di pubbliche amministrazioni, di partecipazioni in societa' quotate, unicamente nei casi in cui l'operazione comporti l'acquisto della qualita' di socio.

## Art. 9. - Gestione delle partecipazioni pubbliche

1. Per le partecipazioni pubbliche statali i diritti del socio sono esercitati dal Ministero dell'economia e delle finanze, di concerto con altri Ministeri competenti per materia, individuati dalle relative disposizioni di legge o di regolamento ministeriale.

2. Per le partecipazioni regionali i diritti del socio sono esercitati secondo la disciplina stabilita dalla regione titolare delle partecipazioni.

3. Per le partecipazioni di enti locali i diritti del socio sono esercitati dal sindaco o dal presidente o da un loro delegato.

4. In tutti gli altri casi i diritti del socio sono esercitati dall'organo amministrativo dell'ente.

5. La conclusione, la modificazione e lo scioglimento di patti parasociali sono deliberati ai sensi dell'articolo 7, comma 1.

6. La violazione delle disposizioni di cui ai commi da 1 a 5 e il contrasto con impegni assunti mediante patti parasociali non determinano l'invalidita' delle deliberazioni degli organi della societa' partecipata, ferma restando la possibilita' che l'esercizio del voto o la deliberazione siano invalidate in applicazione di norme generali di diritto privato.

7. Qualora lo statuto della societa' partecipata preveda, ai sensi dell'articolo 2449 del codice civile, la facolta' del socio pubblico di nominare o revocare direttamente uno o piu' componenti di organi interni della societa', i relativi atti sono efficaci dalla data di ricevimento, da parte della societa', della comunicazione dell'atto di nomina o di revoca. E' fatta salva l'applicazione dell'articolo 2400, secondo comma, del codice civile.

8. Nei casi di cui al comma 7, la mancanza o invalidita' dell'atto deliberativo interno di nomina o di revoca rileva come causa di invalidita' dell'atto di nomina o di revoca anche nei confronti della societa'.

9. Le disposizioni del presente articolo si applicano anche alle partecipazioni di pubbliche amministrazioni nelle societa' quotate.

10. Resta fermo quanto disposto dal decreto-legge 15 marzo 2012, n. 21, convertito, con modificazioni, dalla legge 11 maggio 2012, n. 56.

## Art. 10. - Alienazione di partecipazioni sociali

1. Gli atti deliberativi aventi ad oggetto l'alienazione o la costituzione di vincoli su partecipazioni sociali delle amministrazioni pubbliche sono adottati secondo le modalita' di cui all'articolo 7, comma 1.

2. L'alienazione delle partecipazioni e' effettuata nel rispetto dei principi di pubblicita', trasparenza e non discriminazione. In casi eccezionali, a seguito di deliberazione motivata dell'organo competente ai sensi del comma 1, che da' analiticamente atto della convenienza economica dell'operazione, con particolare riferimento alla congruita' del prezzo di vendita, l'alienazione puo' essere effettuata mediante negoziazione diretta con un singolo acquirente. E' fatto salvo il diritto di prelazione dei soci eventualmente previsto dalla legge o dallo statuto.

3. La mancanza o invalidita' dell'atto deliberativo avente ad oggetto l'alienazione della partecipazione rende inefficace l'atto di alienazione della partecipazione.

4. E' fatta salva la disciplina speciale in materia di alienazione delle partecipazioni dello Stato.

## Art. 11.

Organi amministrativi e di controllo delle societa' a controllo pubblico

1. Salvi gli ulteriori requisiti previsti dallo statuto, i componenti degli organi amministrativi e di controllo di societa' a controllo pubblico devono possedere i requisiti di onorabilita', professionalita' e autonomia stabiliti con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze , previa intesa in Conferenza unificata ai sensi dell'articolo 9 del decreto legislativo 28 agosto 1997, n. 281. Resta fermo quanto disposto dall'articolo 12 del decreto legislativo 8 aprile 2013, n. 39, e dall'articolo 5, comma 9, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135.

2. L'organo amministrativo delle societa' a controllo pubblico e' costituito, di norma, da un amministratore unico.

3. L'assemblea della societa' a controllo pubblico, con delibera motivata con riguardo a specifiche ragioni di adeguatezza organizzativa e tenendo conto delle esigenze di contenimento dei costi, puo' disporre che la societa' sia amministrata da un consiglio di amministrazione composto da tre o cinque membri, ovvero che sia adottato uno dei sistemi alternativi di amministrazione e controllo previsti dai paragrafi 5 e 6 della sezione VI-bis del capo V del titolo V del libro V del codice civile. La delibera e' trasmessa alla sezione della Corte dei conti competente ai sensi dell'articolo 5, comma 4, e alla struttura di cui all'articolo 15.

4. Nella scelta degli amministratori delle societa' a controllo pubblico, le amministrazioni assicurano il rispetto del principio di equilibrio di genere, almeno nella misura di un terzo, da computare sul numero complessivo delle designazioni o nomine effettuate in corso d'anno. Qualora la societa' abbia un organo amministrativo collegiale, lo statuto prevede che la scelta degli amministratori da eleggere sia effettuata nel rispetto dei criteri stabiliti dalla legge 12 luglio 2011, n. 120.

5. Quando la societa' a controllo pubblico sia costituita in forma di societa' a responsabilita' limitata, non e' consentito, in deroga all'articolo 2475, terzo comma, del codice civile, prevedere che l'amministrazione sia affidata, disgiuntamente o congiuntamente, a due o piu' soci.

6. Con decreto del Ministro dell'economia e delle finanze, previo parere delle Commissioni parlamentari competenti, per le societa' a controllo pubblico sono definiti indicatori dimensionali quantitativi e qualitativi al fine di individuare fino a cinque fasce per la classificazione delle suddette societa'. Per le societa' controllate dalle regioni o dagli enti locali, il decreto di cui al primo periodo e' adottato previa intesa in Conferenza unificata ai sensi dell'articolo 9 del decreto legislativo 28 agosto 1997, n. 281. Per ciascuna fascia e' determinato, in proporzione, il limite dei compensi massimi al quale gli organi di dette societa' devono fare riferimento, secondo criteri oggettivi e trasparenti, per la determinazione del trattamento economico annuo onnicomprensivo da corrispondere agli amministratori, ai titolari e componenti degli organi di controllo, ai dirigenti e ai dipendenti, che non potra' comunque eccedere il limite massimo di euro 240.000 annui al lordo dei contributi previdenziali e assistenziali e degli oneri fiscali a carico del beneficiario, tenuto conto anche dei compensi corrisposti da altre pubbliche amministrazioni o da altre societa' a controllo pubblico. Le stesse societa' verificano il rispetto del limite massimo del trattamento economico annuo onnicomprensivo dei propri amministratori e dipendenti fissato con il suddetto decreto. Sono in ogni caso fatte salve le disposizioni legislative e regolamentari che prevedono limiti ai compensi inferiori a quelli previsti dal decreto di cui al presente comma. Il decreto stabilisce altresi' i criteri di determinazione della parte variabile della remunerazione, commisurata ai risultati di bilancio raggiunti dalla societa' nel corso dell'esercizio precedente. In caso di risultati negativi attribuibili alla responsabilita' dell'amministratore, la parte variabile non puo' essere corrisposta.

7. Fino all'emanazione del decreto di cui al comma 6 restano in vigore le disposizioni di cui all'articolo 4, comma 4, secondo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e successive modificazioni, e al decreto del Ministro dell'economia e delle finanze 24 dicembre 2013, n. 166.

8. Gli amministratori delle societa' a controllo pubblico non possono essere dipendenti delle amministrazioni pubbliche controllanti o vigilanti. Qualora siano dipendenti della societa' controllante, in virtu' del principio di onnicomprensivita' della retribuzione, fatto salvo il diritto alla copertura assicurativa e al rimborso delle spese documentate, nel rispetto del limite di spesa di cui al comma 6, essi hanno l'obbligo di riversare i relativi compensi alla societa' di appartenenza. Dall'applicazione del presente comma non possono derivare aumenti della spesa complessiva per i compensi degli amministratori. ((18))

9. Gli statuti delle societa' a controllo pubblico prevedono altresi':

- a) l'attribuzione da parte del consiglio di amministrazione di deleghe di gestione a un solo amministratore, salva l'attribuzione di deleghe al presidente ove preventivamente autorizzata dall'assemblea;
- b) l'esclusione della carica di vicepresidente o la previsione che la carica stessa sia attribuita esclusivamente quale modalita' di individuazione del sostituto del presidente in caso di assenza o impedimento, senza riconoscimento di compensi aggiuntivi;
- c) il divieto di corrispondere gettoni di presenza o premi di risultato deliberati dopo lo svolgimento dell'attivita', e il divieto di corrispondere trattamenti di fine mandato, ai componenti degli organi sociali;
- d) il divieto di istituire organi diversi da quelli previsti dalle norme generali in tema di societa'.

10. E' comunque fatto divieto di corrispondere ai dirigenti delle societa' a controllo pubblico indennita' o trattamenti di fine mandato diversi o ulteriori rispetto a quelli previsti dalla legge o dalla contrattazione collettiva ovvero di stipulare patti o accordi di non concorrenza, anche ai sensi dell'articolo 2125 del codice civile.

11. Nelle societa' di cui amministrazioni pubbliche detengono il controllo indiretto, non e' consentito nominare, nei consigli di amministrazione o di gestione, amministratori della societa' controllante, a meno che siano attribuite ai medesimi deleghe gestionali a carattere continuativo ovvero che la nomina risponda all'esigenza di rendere disponibili alla societa' controllata particolari e comprovate competenze tecniche degli amministratori della societa' controllante o di favorire l'esercizio dell'attivita' di direzione e coordinamento.

12. Coloro che hanno un rapporto di lavoro con societa' a controllo pubblico e che sono al tempo stesso componenti degli organi di amministrazione della societa' con cui e' instaurato il rapporto di lavoro, sono collocati in aspettativa non retribuita e con sospensione della loro iscrizione ai competenti istituti di previdenza e di assistenza, salvo che rinuncino ai compensi dovuti a qualunque titolo agli amministratori.

13. Le societa' a controllo pubblico limitano ai casi previsti dalla legge la costituzione di comitati con funzioni consultive o di proposta. Per il caso di loro costituzione, non puo' comunque essere riconosciuta ai componenti di tali comitati alcuna remunerazione complessivamente superiore al 30 per cento del compenso deliberato per la carica di componente dell'organo amministrativo e comunque proporzionata alla qualificazione professionale e all'entita' dell'impegno richiesto.

14. Restano ferme le disposizioni in materia di inconferibilita' e incompatibilita' di incarichi di cui al decreto legislativo 8 aprile 2013, n. 39.

15. Agli organi di amministrazione e controllo delle societa' in house si applica il decreto-legge 16 maggio 1994, n. 293, convertito, con modificazioni, dalla legge 15 luglio 1994, n. 444.

16. Nelle societa' a partecipazione pubblica ma non a controllo pubblico, l'amministrazione pubblica che sia titolare di una partecipazione pubblica superiore al dieci per cento del capitale propone agli organi societari l'introduzione di misure analoghe a quelle di cui ai commi 6 e 10.

-------------- AGGIORNAMENTO (18) Il D.L. 21 maggio 2025, n. 73, convertito con modificazioni dalla L. 18 luglio 2025, n. 105, ha disposto (con l'art. 8-bis, comma 1) che "In deroga alle disposizioni dell'articolo 11, comma 8, primo periodo, del testo unico in materia di societa' a partecipazione pubblica, di cui al decreto legislativo 19 agosto 2016, n. 175, l'incarico di amministratore unico della societa' ENAC Servizi S.r.l., societa' in house dell'Ente nazionale per l'aviazione civile (ENAC), puo' essere conferito anche a dipendenti dell'ENAC. In tal caso il dipendente e' collocato in aspettativa non retribuita dall'amministrazione di appartenenza, con sospensione delle corrispondenti facolta' assunzionali per la durata dell'incarico. Il compenso dell'amministratore unico e' determinato ai sensi delle disposizioni vigenti. Gli oneri retributivi e previdenziali sono posti interamente a carico dell'ENAC Servizi S.r.l.".

## Art. 12.

Responsabilita' degli enti partecipanti e dei componenti degli organi delle societa' partecipate

1. I componenti degli organi di amministrazione e controllo delle societa' partecipate sono soggetti alle azioni civili di responsabilita' previste dalla disciplina ordinaria delle societa' di capitali, salva la giurisdizione della Corte dei conti per il danno erariale causato dagli amministratori e dai dipendenti delle societa' in house. E' devoluta alla Corte dei conti, nei limiti della quota di partecipazione pubblica, la giurisdizione sulle controversie in materia di danno erariale di cui al comma 2.

2. Costituisce danno erariale il danno, patrimoniale o non patrimoniale, subito dagli enti partecipanti, ivi compreso il danno conseguente alla condotta dei rappresentanti degli enti pubblici partecipanti o comunque dei titolari del potere di decidere per essi, che, nell'esercizio dei propri diritti di socio, abbiano con dolo o colpa grave pregiudicato il valore della partecipazione.

## Art. 13.

Controllo giudiziario sull'amministrazione di societa' a controllo pubblico

1. Nelle societa' a controllo pubblico, in deroga ai limiti minimi di partecipazione previsti dall'articolo 2409 del codice civile, ciascuna amministrazione pubblica socia, indipendentemente dall'entita' della partecipazione di cui e' titolare, e' legittimata a presentare denunzia di gravi irregolarita' al tribunale.

2. Il presente articolo si applica anche alle societa' a controllo pubblico costituite in forma di societa' a responsabilita' limitata.

## Art. 14.

Crisi d'impresa di societa' a partecipazione pubblica

1. Le societa' a partecipazione pubblica sono soggette alle disposizioni sul fallimento e sul concordato preventivo, nonche', ove ne ricorrano i presupposti, a quelle in materia di amministrazione straordinaria delle grandi imprese ((in stato di insolvenza)) di cui al decreto legislativo 8 luglio 1999, n. 270, e al decreto-legge 23 dicembre 2003, n. 347, convertito, con modificazioni, dalla legge 18 febbraio 2004, n. 39.

2. Qualora emergano, nell'ambito dei programmi di valutazione del rischio di cui all'articolo 6, ((comma 2)), uno o piu' indicatori di crisi aziendale, l'organo amministrativo della societa' a controllo pubblico adotta senza indugio i provvedimenti necessari al fine di prevenire l'aggravamento della crisi, di correggerne gli effetti ed eliminarne le cause, attraverso un idoneo piano di risanamento.

3. Quando si determini la situazione di cui al ((comma 2)), la mancata adozione di provvedimenti adeguati, da parte dell'organo amministrativo, costituisce grave irregolarita' ai sensi dell'articolo 2409 del codice civile.

4. Non costituisce provvedimento adeguato, ai sensi dei commi 1 e 2, la previsione di un ripianamento delle perdite da parte dell'amministrazione o delle amministrazioni pubbliche socie, anche se attuato in concomitanza a un aumento di capitale o ad un trasferimento straordinario di partecipazioni o al rilascio di garanzie o in qualsiasi altra forma giuridica, a meno che tale intervento sia accompagnato da un piano di ristrutturazione aziendale, dal quale risulti comprovata la sussistenza di concrete prospettive di recupero dell'equilibrio economico delle attivita' svolte, approvato ai sensi del ((comma 2)), anche in deroga al comma 5.

5. Le amministrazioni di cui all'articolo 1, comma 3, della legge 31 dicembre 2009, n. 196, non possono, salvo quanto previsto dagli articoli 2447 e 2482-ter del codice civile, ((sottoscrivere aumenti di capitale, effettuare trasferimenti straordinari, aperture di credito)), ne' rilasciare garanzie a favore delle societa' partecipate, con esclusione delle societa' quotate e degli istituti di credito, che abbiano registrato, per tre esercizi consecutivi, perdite di esercizio ovvero che abbiano utilizzato riserve disponibili per il ripianamento di perdite anche infrannuali. Sono in ogni caso consentiti i trasferimenti straordinari alle societa' di cui al primo periodo, a fronte di convenzioni, contratti di servizio o di programma relativi allo svolgimento di servizi di pubblico interesse ovvero alla realizzazione di investimenti, purche' le misure indicate siano contemplate in un piano di risanamento, approvato dall'Autorita' di regolazione di settore ove esistente e comunicato alla Corte dei conti con le modalita' di cui all'articolo 5, che contempli il raggiungimento dell'equilibrio finanziario entro tre anni. Al fine di salvaguardare la continuita' nella prestazione di servizi di pubblico interesse, a fronte di gravi pericoli per la sicurezza pubblica, l'ordine pubblico e la sanita', su richiesta della amministrazione interessata, con decreto del Presidente del Consiglio dei ministri, adottato su proposta del Ministro dell'economia e delle finanze, di concerto con gli altri Ministri competenti e soggetto a registrazione della Corte dei conti, possono essere autorizzati gli interventi di cui al primo periodo del presente comma.

6. Nei cinque anni successivi alla dichiarazione di fallimento di una societa' a controllo pubblico titolare di affidamenti diretti, le pubbliche amministrazioni controllanti non possono costituire nuove societa', ne' acquisire o mantenere partecipazioni in societa', qualora le stesse gestiscano i medesimi servizi di quella dichiarata fallita.

## Art. 15.

Monitoraggio, indirizzo e coordinamento sulle societa' a partecipazione pubblica

1. Nell'ambito del Ministero dell'economia e delle finanze, nei limiti delle risorse disponibili a legislazione vigente, ((con decreto del Ministro dell'economia e delle finanze,)) e' individuata la struttura competente per ((l'indirizzo,)) il controllo e il monitoraggio sull'attuazione del presente decreto. Il Ministero dell'economia e delle finanze assicura la separazione, a livello organizzativo, tra la suddetta struttura e gli uffici responsabili dell'esercizio dei diritti sociali.

2. Fatte salve le norme di settore e le competenze dalle stesse previste, ai fini dell'applicazione delle disposizioni del presente decreto, la struttura di cui al comma 1 fornisce orientamenti e indicazioni in materia di applicazione del presente decreto e del decreto legislativo 11 novembre 2003, n. 333, e promuove le migliori pratiche presso le societa' a partecipazione pubblica, adotta nei confronti delle stesse societa' le direttive sulla separazione contabile e verifica il loro rispetto, ivi compresa la relativa trasparenza.

3. La struttura di cui al comma 1 tiene un elenco pubblico, accessibile anche in via telematica, di tutte le societa' a partecipazione pubblica esistenti, utilizzando le informazioni della banca dati di cui all'articolo 17, comma 4, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114.

4. Fermo restando quanto disposto dal citato articolo 17, comma 4, del decreto-legge n. 90 del 2014, le amministrazioni pubbliche e le societa' a partecipazione pubblica inviano alla struttura cui al comma 1, con le modalita' e nei termini da essa stabiliti, le segnalazioni periodiche e ogni altro dato o documento richiesto. Esse trasmettono anche i bilanci e gli altri documenti obbligatori, di cui all'articolo 6 del presente decreto, con le modalita' e nei termini stabiliti dalla medesima struttura.

5. In relazione agli obblighi previsti dal presente decreto, i poteri ispettivi di cui all'articolo 6, comma 3, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, sono esercitati nei confronti di tutte le societa' a partecipazione pubblica.

## Art. 16.

Societa' in house

1. Le societa' in house ricevono affidamenti diretti di contratti pubblici dalle amministrazioni che esercitano su di esse il controllo analogo o da ciascuna delle amministrazioni che esercitano su di esse il controllo analogo congiunto solo se non vi sia partecipazione di capitali privati, ad eccezione di quella prescritta da norme di legge e che avvenga in forme che non comportino controllo o potere di veto, ne' l'esercizio di un'influenza determinante sulla societa' controllata.

2. Ai fini della realizzazione dell'assetto organizzativo di cui al comma 1:

- a) gli statuti delle societa' per azioni possono contenere clausole in deroga delle disposizioni dell'articolo 2380-bis e dell'articolo 2409-novies del codice civile;
- b) gli statuti delle societa' a responsabilita' limitata possono prevedere l'attribuzione all'ente o agli enti pubblici soci di particolari diritti, ai sensi dell'articolo 2468, terzo comma, del codice civile;
- c) in ogni caso, i requisiti del controllo analogo possono essere acquisiti anche mediante la conclusione di appositi patti parasociali; tali patti possono avere durata superiore a cinque anni, in deroga all'articolo 2341-bis, primo comma, del codice civile.

3. Gli statuti delle societa' di cui al presente articolo devono prevedere che oltre l'ottanta per cento del loro fatturato sia effettuato nello svolgimento dei compiti a esse affidati dall'ente pubblico o dagli enti pubblici soci ((...)).

((

3-bis. La produzione ulteriore rispetto al limite di fatturato di cui al comma 3, che puo' essere rivolta anche a finalita' diverse, e' consentita solo a condizione che la stessa permetta di conseguire economie di scala o altri recuperi di efficienza sul complesso dell'attivita' principale della societa'.

))

4. Il mancato rispetto del limite quantitativo di cui al comma 3 costituisce grave irregolarita' ai sensi dell'articolo 2409 del codice civile e dell'articolo 15 del presente decreto.

5. Nel caso di cui al comma 4, la societa' puo' sanare l'irregolarita' se, entro tre mesi dalla data in cui la stessa si e' manifestata, rinunci a una parte dei rapporti ((...)) con soggetti terzi, sciogliendo i relativi rapporti contrattuali, ovvero rinunci agli affidamenti diretti da parte dell'ente o degli enti pubblici soci, sciogliendo i relativi rapporti. In quest'ultimo caso le attivita' precedentemente affidate alla societa' controllata devono essere riaffidate, dall'ente o dagli enti pubblici soci, mediante procedure competitive regolate dalla disciplina in materia di contratti pubblici, entro i sei mesi successivi allo scioglimento del rapporto contrattuale. Nelle more dello svolgimento delle procedure di gara i beni o servizi continueranno ad essere forniti dalla stessa societa' controllata.

6. Nel caso di rinuncia agli affidamenti diretti, di cui al comma 5, la societa' puo' continuare la propria attivita' se e in quanto sussistano i requisiti di cui all'articolo 4. A seguito della cessazione degli affidamenti diretti, perdono efficacia le clausole statutarie e i patti parasociali finalizzati a realizzare i requisiti del controllo analogo.

7. Le societa' di cui al presente articolo sono tenute all'acquisto di lavori, beni e servizi secondo la disciplina di cui al decreto legislativo n. 50 del 2016. Resta fermo quanto previsto ((dagli articoli 5 e)) 192 del medesimo decreto legislativo n. 50 del 2016.

## Art. 17.

Societa' a partecipazione mista pubblico-privata

1. Nelle societa' ((a partecipazione mista pubblico-privata)) la quota di partecipazione del soggetto privato non puo' essere inferiore al trenta per cento e la selezione del medesimo si svolge con procedure di evidenza pubblica a norma dell'articolo 5, comma 9, del decreto legislativo n. 50 del 2016 e ha a oggetto, al contempo, la sottoscrizione o l'acquisto della partecipazione societaria da parte del socio privato e l'affidamento del contratto di appalto o di concessione oggetto esclusivo dell'attivita' della societa' mista.

2. Il socio privato deve possedere i requisiti di qualificazione previsti da norme legali o regolamentari in relazione alla prestazione per cui la societa' e' stata costituita. All'avviso pubblico sono allegati la bozza dello statuto e degli eventuali accordi parasociali, nonche' degli elementi essenziali del contratto di servizio e dei disciplinari e regolamenti di esecuzione che ne costituiscono parte integrante. Il bando di gara deve specificare l'oggetto dell'affidamento, i necessari requisiti di qualificazione generali e speciali di carattere tecnico ed economico-finanziario dei concorrenti, nonche' il criterio di aggiudicazione che garantisca una valutazione delle offerte in condizioni di concorrenza effettiva in modo da individuare un vantaggio economico complessivo per l'amministrazione pubblica che ha indetto la procedura. I criteri di aggiudicazione possono includere, tra l'altro, aspetti qualitativi ambientali, sociali connessi all'oggetto dell'affidamento o relativi all'innovazione.

3. La durata della partecipazione privata alla societa', aggiudicata ai sensi del comma 1 del presente articolo, non puo' essere superiore alla durata dell'appalto o della concessione. Lo statuto prevede meccanismi idonei a determinare lo scioglimento del rapporto societario in caso di risoluzione del contratto di servizio.

4. Nelle societa' di cui al presente articolo:

- a) gli statuti delle societa' per azioni possono contenere clausole in deroga delle disposizioni dell'articolo 2380-bis e dell'articolo 2409-novies del codice civile al fine di consentire il controllo interno del socio pubblico sulla gestione dell'impresa;
- b) gli statuti delle societa' a responsabilita' limitata possono prevedere l'attribuzione all'ente o agli enti pubblici partecipanti e ai soci privati di particolari diritti, ai sensi dell'articolo 2468, terzo comma, del codice civile, e derogare all'articolo 2479, primo comma, del codice civile nel senso di eliminare o limitare la competenza dei soci;
- c) gli statuti delle societa' per azioni possono prevedere l'emissione di speciali categorie di azioni e di azioni con prestazioni accessorie da assegnare al socio privato;
- d) i patti parasociali possono avere durata superiore a cinque anni, in deroga all'articolo 2341-bis, primo comma, del codice civile, purche' entro i limiti di durata del contratto per la cui esecuzione la societa' e' stata costituita.

5. Nel rispetto delle disposizioni del presente articolo, al fine di ottimizzare la realizzazione e la gestione di piu' opere e servizi, anche non simultaneamente assegnati, la societa' puo' emettere azioni correlate ai sensi dell'articolo 2350, secondo comma, del codice civile, o costituire patrimoni destinati o essere assoggettata a direzione e coordinamento da parte di un'altra societa'.

6. Alle societa' di cui al presente articolo che non siano organismi di diritto pubblico, costituite per la realizzazione di lavori o opere o per la produzione di beni o servizi non destinati ad essere collocati sul mercato in regime di concorrenza, per la realizzazione dell'opera pubblica o alla gestione del servizio per i quali sono state specificamente costituite non si applicano le disposizioni del decreto legislativo n. 50 del 2016, se ricorrono le seguenti condizioni:

- a) la scelta del socio privato e' avvenuta nel rispetto di procedure di evidenza pubblica;
- b) il socio privato ha i requisiti di qualificazione previsti dal decreto legislativo n. 50 del 2016 in relazione alla prestazione per cui la societa' e' stata costituita;
- c) la societa' provvede in via diretta alla realizzazione dell'opera o del servizio, in misura superiore al 70% del relativo importo.

## Art. 18.

Quotazione di societa' a controllo pubblico in mercati regolamentati

1. Le societa' controllate da una o piu' amministrazioni pubbliche possono quotare azioni o altri strumenti finanziari in mercati regolamentati, a seguito di deliberazione adottata ai sensi dell'articolo 5, comma 1, secondo le modalita' di cui all'articolo 7, comma 1. L'atto deliberativo prevede uno specifico programma avente ad oggetto il mantenimento o la progressiva dismissione del controllo pubblico sulla societa' quotata.

2. L'atto deliberativo avente ad oggetto la richiesta di ammissione alla quotazione e' adottato con le modalita' di cui all'articolo 7, comma 1.

3. E' fatta salva la possibilita' di quotazione in mercati regolamentati di societa' a partecipazione pubblica singolarmente individuate, soggette a regimi speciali in base ad apposite norme di legge.

## Art. 19. - Gestione del personale

1. Salvo quanto previsto dal presente decreto, ai rapporti di lavoro dei dipendenti delle societa' a controllo pubblico si applicano le disposizioni del capo I, titolo II, del libro V del codice civile, dalle leggi sui rapporti di lavoro subordinato nell'impresa, ivi incluse quelle in materia di ammortizzatori sociali, secondo quanto previsto dalla normativa vigente, e dai contratti collettivi.

2. Le societa' a controllo pubblico stabiliscono, con propri provvedimenti, criteri e modalita' per il reclutamento del personale nel rispetto dei principi, anche di derivazione europea, di trasparenza, pubblicita' e imparzialita' e dei principi di cui all'articolo 35, comma 3, del decreto legislativo 30 marzo 2001, n. 165. In caso di mancata adozione dei suddetti provvedimenti, trova diretta applicazione il suddetto articolo 35, comma 3, del decreto legislativo n. 165 del 2001.

3. I provvedimenti di cui al comma 2 sono pubblicati sul sito istituzionale della societa'. In caso di mancata o incompleta pubblicazione si applicano gli articoli 22, comma 4, 46 e 47, comma 2, del decreto legislativo 14 marzo 2013, n. 33.

4. Salvo quanto previsto dall'articolo 2126 del codice civile, ai fini retributivi, i contratti di lavoro stipulati in assenza dei provvedimenti o delle procedure di cui al comma 2, sono nulli. Resta ferma la giurisdizione ordinaria sulla validita' dei provvedimenti e delle procedure di reclutamento del personale.

5. Le amministrazioni pubbliche socie fissano, con propri provvedimenti, obiettivi specifici, annuali e pluriennali, sul complesso delle spese di funzionamento, ivi comprese quelle per il personale, delle societa' controllate, anche attraverso il contenimento degli oneri contrattuali e delle assunzioni di personale e tenuto conto di quanto stabilito all'articolo 25, ovvero delle eventuali disposizioni che stabiliscono, a loro carico, divieti o limitazioni alle assunzioni di personale, tenendo conto del settore in cui ciascun soggetto opera.

6. Le societa' a controllo pubblico garantiscono il concreto perseguimento degli obiettivi di cui al comma 5 tramite propri provvedimenti da recepire, ove possibile, nel caso del contenimento degli oneri contrattuali, in sede di contrattazione di secondo livello.

7. I provvedimenti e i contratti di cui ai commi 5 e 6 sono pubblicati sul sito istituzionale della societa' e delle pubbliche amministrazioni socie. In caso di mancata o incompleta pubblicazione si applicano l'articolo 22, comma 4, 46 e 47, comma 2, del decreto legislativo 14 marzo 2013, n. 33.

8. Le pubbliche amministrazioni titolari di partecipazioni di controllo in societa', in caso di reinternalizzazione di funzioni o servizi esternalizzati, affidati alle societa' stesse, procedono, prima di poter effettuare nuove assunzioni, al riassorbimento delle unita' di personale gia' dipendenti a tempo indeterminato da amministrazioni pubbliche e transitate alle dipendenze della societa' interessata dal processo di reinternalizzazione, mediante l'utilizzo delle procedure di mobilita' di cui all'articolo 30 del decreto legislativo n. 165 del 2001 e nel rispetto dei vincoli in materia di finanza pubblica e contenimento delle spese di personale. Il riassorbimento puo' essere disposto solo nei limiti dei posti vacanti nelle dotazioni organiche dell'amministrazione interessata e nell'ambito delle facolta' assunzionali disponibili. La spesa per il riassorbimento del personale gia' in precedenza dipendente dalle stesse amministrazioni con rapporto di lavoro a tempo indeterminato non rileva nell'ambito delle facolta' assunzionali disponibili e, per gli enti territoriali, anche del parametro di cui all'articolo 1, comma 557-quater, della legge n. 296 del 2006, a condizione che venga fornita dimostrazione, certificata dal parere dell'organo di revisione economico-finanziaria, che le esternalizzazioni siano state effettuate nel rispetto degli adempimenti previsti dall'articolo 6-bis del decreto legislativo 30 marzo 2001, n. 165, e, in particolare, a condizione che:

- a) in corrispondenza del trasferimento alla societa' della funzione sia stato trasferito anche il personale corrispondente alla funzione medesima, con le correlate risorse stipendiali;
- b) la dotazione organica dell'ente sia stata corrispondentemente ridotta e tale contingente di personale non sia stato sostituito;
- c) siano state adottate le necessarie misure di riduzione dei fondi destinati alla contrattazione integrativa;
- d) l'aggregato di spesa complessiva del personale soggetto ai vincoli di contenimento sia stato ridotto in misura corrispondente alla spesa del personale trasferito alla societa'. (2)

9. Le disposizioni di cui all'articolo 1, commi da 565 a 568 della legge 27 dicembre 2013, n. 147, continuano ad applicarsi fino alla data di pubblicazione del decreto di cui all'articolo 25, comma 1, e comunque non oltre il 31 dicembre 2017.

((9-bis. Al personale di cui al presente articolo e al personale dipendente di enti pubblici non economici, anche per esigenze strettamente collegate all'attuazione del Piano nazionale di ripresa e resilienza si applicano, in quanto compatibili, le disposizioni di cui agli articoli 30 del decreto legislativo 10 settembre 2003, n. 276, e 56 del testo unico di cui al decreto del Presidente della Repubblica 10 gennaio 1957, n. 3. Restano fermi, per le amministrazioni riceventi, i limiti quantitativi stabiliti dall'articolo 30, comma 1-quinquies, del decreto legislativo 30 marzo 2001, n. 165. I comandi o distacchi di cui al presente articolo non possono eccedere la durata di un anno e, comunque, non possono essere utilizzati oltre il 31 dicembre 2026))

-------------- AGGIORNAMENTO (2) La L. 27 dicembre 2017, n. 205, ha disposto (con l'art. 1, comma 872) che "Le disposizioni degli articoli 19, comma 8, e 25 del testo unico in materia di societa' a partecipazione pubblica, di cui al decreto legislativo 19 agosto 2016, n. 175, si applicano, salva diversa disciplina normativa a tutela dei lavoratori, anche ai dipendenti dei consorzi e delle aziende costituiti, rispettivamente, ai sensi degli articoli 31 e 114 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, che, alla data di entrata in vigore del predetto testo unico di cui al decreto legislativo n. 175 del 2016, risultino gia' posti in liquidazione da parte di amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165".

## Art. 20. - Razionalizzazione periodica delle partecipazioni pubbliche

1. Fermo quanto previsto dall'articolo 24, comma 1, le amministrazioni pubbliche effettuano annualmente, con proprio provvedimento, un'analisi dell'assetto complessivo delle societa' in cui detengono partecipazioni, dirette o indirette, predisponendo, ove ricorrano i presupposti di cui al comma 2, un piano di riassetto per la loro razionalizzazione, fusione o soppressione, anche mediante messa in liquidazione o cessione. Fatto salvo quanto previsto dall'articolo 17, comma 4, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, le amministrazioni che non detengono alcuna partecipazione lo comunicano alla sezione della Corte dei conti competente ai sensi dell'articolo 5, comma 4, e alla struttura di cui all'articolo 15.

2. I piani di razionalizzazione, corredati di un'apposita relazione tecnica, con specifica indicazione di modalita' e tempi di attuazione, sono adottati ove, in sede di analisi di cui al comma 1, le amministrazioni pubbliche rilevino:

- a) partecipazioni societarie che non rientrino in alcuna delle categorie di cui all'articolo 4;
- b) societa' che risultino prive di dipendenti o abbiano un numero di amministratori superiore a quello dei dipendenti;
- c) partecipazioni in societa' che svolgono attivita' analoghe o similari a quelle svolte da altre societa' partecipate o da enti pubblici strumentali;
- d) partecipazioni in societa' che, nel triennio precedente, abbiano conseguito un fatturato medio non superiore a un milione di euro;
- e) partecipazioni in societa' diverse da quelle costituite per la gestione di un servizio d'interesse generale che abbiano prodotto un risultato negativo per quattro dei cinque esercizi precedenti;
- f) necessita' di contenimento dei costi di funzionamento;
- g) necessita' di aggregazione di societa' aventi ad oggetto le attivita' consentite all'articolo 4.

3. I provvedimenti di cui ai commi 1 e 2 sono adottati entro il 31 dicembre di ogni anno e sono trasmessi con le modalita' di cui all'articolo 17 del decreto-legge n. 90 del 2014, convertito, con modificazioni, dalla legge di conversione 11 agosto 2014, n. 114 e rese disponibili alla struttura di cui all'articolo 15 e alla sezione di controllo della Corte dei conti competente ai sensi dell'articolo 5, comma 4.

4. In caso di adozione del piano di razionalizzazione, entro il 31 dicembre dell'anno successivo le pubbliche amministrazioni approvano una relazione sull'attuazione del piano, evidenziando i risultati conseguiti, e la trasmettono alla struttura di cui all'articolo 15 e alla sezione di controllo della Corte dei conti competente ai sensi dell'articolo 5, comma 4.

5. I piani di riassetto possono prevedere anche la dismissione o l'assegnazione in virtu' di operazioni straordinarie delle partecipazioni societarie acquistate anche per espressa previsione normativa. I relativi atti di scioglimento delle societa' o di alienazione delle partecipazioni sociali sono disciplinati, salvo quanto diversamente disposto nel presente decreto, dalle disposizioni del codice civile e sono compiuti anche in deroga alla previsione normativa originaria riguardante la costituzione della societa' o l'acquisto della partecipazione.

6. Resta ferma la disposizione dell'articolo 1, comma 568-bis, della legge 27 dicembre 2013, n. 147.

7. La mancata adozione degli atti di cui ai commi da 1 a 4 da parte degli enti locali comporta la sanzione amministrativa del pagamento di una somma da un minimo di euro 5.000 a un massimo di euro 500.000, salvo il danno eventualmente rilevato in sede di giudizio amministrativo contabile, comminata dalla competente sezione giurisdizionale regionale della Corte dei conti" . Si applica l'articolo 24, commi 5, 6, 7, 8 e 9.

8. Resta fermo quanto previsto dall'articolo 29, comma 1-ter, del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111, e dall'articolo 1, commi da 611 a 616, della legge 23 dicembre 2014, n. 190.

9. Entro un anno dalla data di entrata in vigore del presente decreto, il conservatore del registro delle imprese cancella d'ufficio dal registro delle imprese, con gli effetti previsti dall'articolo 2495 del codice civile, le societa' a controllo pubblico che, per oltre ((due anni)) consecutivi, non abbiano depositato il bilancio d'esercizio ovvero non abbiano compiuto atti di gestione. Prima di procedere alla cancellazione, il conservatore comunica l'avvio del procedimento agli amministratori o ai liquidatori, che possono, entro 60 giorni, presentare formale e motivata domanda di prosecuzione dell'attivita', corredata dell'atto deliberativo delle amministrazioni pubbliche socie, adottata nelle forme e con i contenuti previsti dall'articolo 5. In caso di regolare presentazione della domanda, non si da' seguito al procedimento di cancellazione. Unioncamere presenta, entro due anni dalla data di entrata in vigore del presente decreto, alla struttura di cui all'articolo 15, una dettagliata relazione sullo stato di attuazione della presente norma.

## Art. 21.

Norme finanziarie sulle societa' partecipate dalle amministrazioni locali

1. Nel caso in cui societa' partecipate dalle pubbliche amministrazioni locali comprese nell'elenco di cui all'articolo 1, comma 3, della legge 31 dicembre 2009, n. 196, presentino un risultato di esercizio negativo, le pubbliche amministrazioni locali partecipanti, che adottano la contabilita' finanziaria, accantonano nell'anno successivo in apposito fondo vincolato un importo pari al risultato negativo non immediatamente ripianato, in misura proporzionale alla quota di partecipazione. Le pubbliche amministrazioni locali che adottano la contabilita' civilistica adeguano il valore della partecipazione, nel corso dell'esercizio successivo, all'importo corrispondente alla frazione del patrimonio netto della societa' partecipata ove il risultato negativo non venga immediatamente ripianato e costituisca perdita durevole di valore. Per le societa' che redigono il bilancio consolidato, il risultato di esercizio e' quello relativo a tale bilancio. Limitatamente alle societa' che svolgono servizi pubblici a rete di rilevanza economica, per risultato si intende la differenza tra valore e costi della produzione ai sensi dell'articolo 2425 del codice civile. L'importo accantonato e' reso disponibile in misura proporzionale alla quota di partecipazione nel caso in cui l'ente partecipante ripiani la perdita di esercizio o dismetta la partecipazione o il soggetto partecipato sia posto in liquidazione. Nel caso in cui i soggetti partecipati ripianino in tutto o in parte le perdite conseguite negli esercizi precedenti l'importo accantonato viene reso disponibile agli enti partecipanti in misura corrispondente e proporzionale alla quota di partecipazione.

2. Gli accantonamenti e le valutazioni di cui al comma 1 si applicano a decorrere dall'anno 2015. In sede di prima applicazione, per gli anni 2015, 2016 e 2017, in presenza di adozione della contabilita' finanziaria:

- a) l'ente partecipante a societa' che hanno registrato nel triennio 2011-2013 un risultato medio negativo accantona, in proporzione alla quota di partecipazione, una somma pari alla differenza tra il risultato conseguito nell'esercizio precedente e il risultato medio 2011-2013 migliorato, rispettivamente, del 25 per cento per il 2014, del 50 per cento per il 2015 e del 75 per cento per il 2016; qualora il risultato negativo sia peggiore di quello medio registrato nel triennio 2011-2013, l'accantonamento e' operato nella misura indicata dalla lettera b);
- b) l'ente partecipante a societa' che hanno registrato nel triennio 2011-2013 un risultato medio non negativo accantona, in misura proporzionale alla quota di partecipazione, una somma pari al 25 per cento per il 2015, al 50 per cento per il 2016 e al 75 per cento per il 2017 del risultato negativo conseguito nell'esercizio precedente.

3. Le societa' a partecipazione di maggioranza, diretta e indiretta, delle pubbliche amministrazioni locali titolari di affidamento diretto da parte di soggetti pubblici per una quota superiore all'80 per cento del valore della produzione, che nei tre esercizi precedenti abbiano conseguito un risultato economico negativo, procedono alla riduzione del 30 per cento del compenso dei componenti degli organi di amministrazione. Il conseguimento di un risultato economico negativo per due anni consecutivi rappresenta giusta causa ai fini della revoca degli amministratori. Quanto previsto dal presente comma non si applica ai soggetti il cui risultato economico, benche' negativo, sia coerente con un piano di risanamento preventivamente approvato dall'ente controllante.

((

3-bis. Le pubbliche amministrazioni locali partecipanti possono procedere al ripiano delle perdite subite dalla societa' partecipata con le somme accantonate ai sensi del comma 1, nei limiti della loro quota di partecipazione e nel rispetto dei principi e della legislazione dell'Unione europea in tema di aiuti di Stato.

))

## Art. 22. - Trasparenza

1. Le societa' a controllo pubblico assicurano il massimo livello di trasparenza sull'uso delle proprie risorse e sui risultati ottenuti, secondo le previsioni del decreto legislativo 14 marzo 2013, n. 33.

## Art. 23. - Clausola di salvaguardia

1. Le disposizioni del presente decreto si applicano nelle Regioni a statuto speciale e nelle province autonome di Trento e di Bolzano compatibilmente con i rispettivi statuti e le relative norme di attuazione, anche con riferimento alla legge costituzionale 18 ottobre 2001, n. 3.

## Art. 24. - Revisione straordinaria delle partecipazioni

1. Le partecipazioni detenute, direttamente o indirettamente, dalle amministrazioni pubbliche alla data di entrata in vigore del presente decreto in societa' non riconducibili ad alcuna delle categorie di cui all'articolo 4, ovvero che non soddisfano i requisiti di cui all'articolo 5, commi 1 e 2, o che ricadono in una delle ipotesi di cui all'articolo 20, comma 2, sono alienate o sono oggetto delle misure di cui all'articolo 20, commi 1 e 2. A tal fine, entro il 30 settembre 2017, ciascuna amministrazione pubblica effettua con provvedimento motivato la ricognizione di tutte le partecipazioni possedute alla data di entrata in vigore del presente decreto, individuando quelle che devono essere alienate. L'esito della ricognizione, anche in caso negativo, e' comunicato con le modalita' di cui all'articolo 17 del decreto-legge n. 90 del 2014, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114. Le informazioni sono rese disponibili alla sezione della Corte dei conti competente ai sensi dell'articolo 5, comma 4, e alla struttura di cui all'articolo 15.

2. Per le amministrazioni di cui all'articolo 1, comma 611, della legge 23 dicembre 2014, n. 190, il provvedimento di cui al comma 1 costituisce aggiornamento del piano operativo di razionalizzazione adottato ai sensi del comma 612 dello stesso articolo, fermi restando i termini ivi previsti.

3. Il provvedimento di ricognizione e' inviato alla sezione della Corte dei conti competente ai sensi dell'articolo 5, comma 4, nonche' alla struttura di cui all'articolo 15, perche' verifichi il puntuale adempimento degli obblighi di cui al presente articolo. (1)

4. L'alienazione, da effettuare ai sensi dell'articolo 10, avviene entro un anno dalla conclusione della ricognizione di cui al comma 1.

5. In caso di mancata adozione dell'atto ricognitivo ovvero di mancata alienazione entro i termini previsti dal comma 4, il socio pubblico non puo' esercitare i diritti sociali nei confronti della societa' e, salvo in ogni caso il potere di alienare la partecipazione, la medesima e' liquidata in denaro in base ai criteri stabiliti all'articolo 2437-ter, secondo comma, e seguendo il procedimento di cui all'articolo 2437-quater del codice civile. (1)

5-bis. A tutela del patrimonio pubblico e del valore delle quote societarie pubbliche, fino al 31 dicembre 2021 le disposizioni dei commi 4 e 5 non si applicano nel caso in cui le societa' partecipate abbiano prodotto un risultato medio in utile nel triennio precedente alla ricognizione. L'amministrazione pubblica che detiene le partecipazioni e' conseguentemente autorizzata a non procedere all'alienazione.

((5-ter. Le disposizioni del comma 5-bis si applicano anche per l'anno 2022 nel caso in cui le societa' partecipate abbiano prodotto un risultato medio in utile nel triennio 2017-2019))

6. Nei casi di cui al sesto e al settimo comma dell'articolo 2437-quater del codice civile ovvero in caso di estinzione della partecipazione in una societa' unipersonale, la societa' e' posta in liquidazione.

7. Gli obblighi di alienazione di cui al comma 1 valgono anche nel caso di partecipazioni societarie acquistate in conformita' ad espresse previsioni normative, statali o regionali.

8. Per l'attuazione dei provvedimenti di cui al comma 1, si applica l'articolo 1, commi 613 e 614, della legge n. 190 del 2014.

9. All'esclusivo fine di favorire i processi di cui al presente articolo, in occasione della prima gara successiva alla cessazione dell'affidamento in favore della societa' a controllo pubblico interessata da tali processi, il rapporto di lavoro del personale gia' impiegato nell'appalto o nella concessione continua con il subentrante nell'appalto o nella concessione ai sensi dell'articolo 2112 del codice civile.

--------------- AGGIORNAMENTO (1) Il D.Lgs. 16 giugno 2017, n. 100 ha disposto (con l'art. 21, comma 2) che "Le disposizioni di cui all'articolo 24, commi 3 e 5, del decreto legislativo n. 175 del 2016 si applicano a decorrere dal 1° ottobre 2017 e sono fatti salvi gli atti di esercizio dei diritti sociali di cui al predetto articolo 24, comma 5, compiuti dal socio pubblico sino alla data di entrata in vigore del presente decreto".

## Art. 25. - ((Disposizioni in materia di personale))

((

1. Entro il 30 settembre di ciascuno degli anni 2020, 2021 e 2022, le societa' a controllo pubblico effettuano una ricognizione del personale in servizio, per individuare eventuali eccedenze, anche in relazione a quanto previsto dall'articolo 24. L'elenco del personale eccedente, con la puntuale indicazione dei profili posseduti, e' trasmesso alla regione nel cui territorio la societa' ha sede legale secondo modalita' stabilite con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro per la pubblica amministrazione e con il Ministro dell'economia e delle finanze, previa intesa in sede di Conferenza unificata ai sensi dell'articolo 8, comma 6, della legge 5 giugno 2003, n. 131.

2. Le regioni formano e gestiscono l'elenco dei lavoratori dichiarati eccedenti ai sensi del comma 1 e agevolano processi di mobilita' in ambito regionale, con le modalita' stabilite dal decreto previsto dal medesimo comma 1 e previo accordo con le organizzazioni sindacali comparativamente piu' rappresentative, tramite riallocazione totale o parziale del personale in eccedenza presso altre societa' controllate dal medesimo ente o da altri enti della stessa regione, sulla base di un accordo tra le societa' interessate.

3. Decorsi dodici mesi dalla scadenza dei termini di cui al comma 1, le regioni trasmettono gli elenchi dei lavoratori dichiarati eccedenti e non ricollocati all'Agenzia nazionale per le politiche attive del lavoro, che gestisce, d'intesa con ciascuna regione territorialmente competente, l'elenco dei lavoratori dichiarati eccedenti e non ricollocati))

((5))

-------------- AGGIORNAMENTO (5) Il D.L. 30 dicembre 2019, n. 162, convertito con modificazioni dalla L. 28 febbraio 2020, n. 8, ha disposto (con l'art. 1, comma 10-decies) che "Fermi restando gli obblighi di riassorbimento del personale stabiliti dal comma 8 dell'articolo 19 del testo unico di cui al decreto legislativo 19 agosto 2016, n. 175, le disposizioni di cui al comma 10-novies del presente articolo si applicano, salva diversa disciplina normativa a tutela dei lavoratori, anche ai dipendenti dei consorzi e delle aziende costituiti, rispettivamente, ai sensi degli articoli 31 e 114 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, che, alla data di entrata in vigore della legge di conversione del presente decreto, risultino gia' posti in liquidazione da parte delle amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165".

## Art. 26. - Altre disposizioni transitorie

1. Le societa' a controllo pubblico gia' costituite all'atto dell'entrata in vigore del presente decreto adeguano i propri statuti alle disposizioni del presente decreto entro il 31 luglio 2017. Per le disposizioni dell'articolo 17, comma 1, il termine per l'adeguamento e' fissato al 31 dicembre 2017.

2. L'articolo 4 del presente decreto non e' applicabile alle societa' elencate nell'allegato A, nonche' alle societa' aventi come oggetto sociale esclusivo la gestione di fondi europei per conto dello Stato o delle regioni, ovvero la realizzazione di progetti di ricerca finanziati dalle istituzioni dell'Unione europea.

3. Le pubbliche amministrazioni possono comunque mantenere le partecipazioni in societa' quotate detenute al 31 dicembre 2015.

4. Nei diciotto mesi successivi alla sua entrata in vigore, il presente decreto non si applica alle societa' in partecipazione pubblica che abbiano deliberato la quotazione delle proprie azioni in mercati regolamentati con provvedimento comunicato alla Corte dei conti. Ove entro il suddetto termine la societa' interessata abbia presentato domanda di ammissione alla quotazione, il presente decreto continua a non applicarsi alla stessa societa' fino alla conclusione del procedimento di quotazione.

5. Nei dodici mesi successivi alla sua entrata in vigore, il presente decreto non si applica alle societa' in partecipazione pubblica che, entro la data del 30 giugno 2016, abbiano adottato atti volti all'emissione di strumenti finanziari, diversi dalle azioni, quotati in mercati regolamentati. I suddetti atti sono comunicati alla Corte dei conti entro sessanta giorni dalla data di entrata in vigore del presente decreto. Ove entro il suddetto termine di dodici mesi il procedimento di quotazione si sia concluso, il presente decreto continua a non applicarsi alla stessa societa'. Sono comunque fatti salvi, anche in deroga all'articolo 7, gli effetti degli atti volti all'emissione di strumenti finanziari, diversi dalle azioni, quotati in mercati regolamentati, adottati prima della data di entrata in vigore del presente decreto.

5-bis. Alle societa' emittenti strumenti finanziari, diversi dalle azioni, quotati in mercati regolamentati, soggette alla disciplina di cui all'articolo 1, comma 5, e ((al comma 5 del presente articolo)), continuano ad applicarsi le disposizioni contenute nei medesimi commi in virtu' della proroga dello strumento finanziario o di successive emissioni effettuate in sostanziale continuita'.

6. Le disposizioni degli articoli 4, 17, 19 e 25 non si applicano alle societa' a partecipazione pubblica derivanti da una sperimentazione gestionale costituite ai sensi dell'articolo 9-bis del decreto legislativo 30 dicembre 1992, n. 502.

6-bis. Le disposizioni dell'articolo 20 non si applicano alle societa' a partecipazione pubblica di cui all'articolo 4, comma 6.

7. Sono fatte salve, fino al completamento dei relativi progetti, le partecipazioni pubbliche nelle societa' costituite per il coordinamento e l'attuazione dei patti territoriali e dei contratti d'area per lo sviluppo locale, ai sensi della delibera Cipe 21 marzo 1997.

8. Ove alla data di entrata in vigore del presente decreto non sia stato adottato il decreto previsto dall'articolo 1, comma 672, della legge 28 dicembre 2015, n. 208, il decreto di cui all'articolo 11, comma 6 e' adottato entro trenta giorni dalla suddetta data.

9. Al decreto legislativo 23 giugno 2011, n. 118, sono apportate le seguenti modificazioni:

- a) all'articolo 11-quater, comma 1, le parole: «Si definisce» sono sostituite dalle seguenti: «Ai fini dell'elaborazione del bilancio consolidato, si definisce»;
- b) all'articolo 11-quinquies, comma 1, le parole: «Per societa' partecipata» sono sostituite dalle seguenti: «Ai fini dell'elaborazione del bilancio consolidato, per societa' partecipata».

10. Le societa' a controllo pubblico si adeguano alle previsioni dell'articolo 11, comma 8, entro il 31 luglio 2017.

11. Salva l'immediata applicazione della disciplina sulla revisione straordinaria di cui all'articolo 24, alla razionalizzazione periodica di cui all'articolo 20 si procede a partire dal 2018, con riferimento alla situazione al 31 dicembre 2017.

12. Al fine di favorire il riordino delle partecipazioni dello Stato e di dare piena attuazione alla previsione di cui all'articolo 9, comma 1, ove entro il 31 ottobre 2016 pervenga la proposta dei relativi ministri, con decreto del Presidente del Consiglio dei ministri la titolarita' delle partecipazioni societarie delle altre amministrazioni statali e' trasferita al Ministero dell'economia e delle finanze, anche in deroga alla previsione normativa originaria riguardante la costituzione della societa' o l'acquisto della partecipazione.

12-bis. Sono escluse dall'applicazione del presente decreto le societa' destinatarie dei provvedimenti di cui al decreto legislativo 6 settembre 2011, n. 159, nonche' la societa' di cui all'articolo 7 del decreto-legge 3 maggio 2016, n. 59, convertito, con modificazioni, dalla legge 30 giugno 2016, n. 119.

12-ter. Per le societa' di cui all'articolo 4, comma 8, le disposizioni dell'articolo 20 trovano applicazione decorsi 5 anni dalla loro costituzione.

12-quater. Per le societa' di cui all'articolo 4, comma 7, solo ai fini della prima applicazione del criterio di cui all'articolo 20, comma 2, lettera e), si considerano i risultati dei cinque esercizi successivi all'entrata in vigore del presente decreto.

12-quinquies. Ai fini dell'applicazione del criterio di cui all'articolo 20, comma 2, lettera d), il primo triennio rilevante e' il triennio 2017-2019. Nelle more della prima applicazione del suddetto criterio relativo al triennio 2017-2019, si applica la soglia di fatturato medio non superiore a cinquecentomila euro per il triennio precedente l'entrata in vigore del presente decreto ai fini dell'adozione dei piani di revisione straordinaria di cui all'articolo 24 e per i trienni 2015-2017 e 2016-2018 ai fini dell'adozione dei piani di razionalizzazione di cui all'articolo 20.

12-sexies. In deroga all'articolo 4, le amministrazioni pubbliche possono acquisire o mantenere partecipazioni nelle societa' che, alla data di entrata in vigore del presente decreto legislativo, risultano gia' costituite e autorizzate alla gestione delle case da gioco ai sensi della legislazione vigente. Con riguardo a tali societa', le disposizioni di cui all'articolo 20, comma 2, lettere a) ed e), non trovano applicazione e le disposizioni di cui all'articolo 14, comma 5, si applicano a decorrere dal 31 maggio 2018.

## Art. 27. - Coordinamento con la legislazione vigente

1. All'articolo 18 del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133 sono apportate le seguenti modificazioni:

- a) nella rubrica, le parole: «delle societa'» sono sostituite dalle seguenti: «delle aziende e istituzioni»;
- b) al comma 2-bis, le parole: «Le aziende speciali, le istituzioni e le societa' a partecipazione pubblica locale totale o di controllo», ovunque occorrano, sono sostituite dalle seguenti: «Le aziende speciali e le istituzioni».

2. All'articolo 1 della legge 27 dicembre 2013, n. 147, sono apportate le seguenti modificazioni:

- a) al comma 550, le parole: «alle aziende speciali, alle istituzioni e alle societa'» sono sostituite dalle seguenti: «alle aziende speciali e alle istituzioni»;
- b) al comma 554, le parole: «le aziende speciali, le istituzioni e le societa'» sono sostituite dalle seguenti: «le aziende speciali e le istituzioni»;
- c) al comma 555, le parole: «diversi dalle societa' che svolgono servizi pubblici locali» sono soppresse.

((

2-bis. Resta fermo quanto previsto dall'articolo 3-bis, comma 2-bis, del decreto-legge 13 agosto 2011, n. 138, convertito, con modificazioni, dalla legge 14 settembre 2011, n. 148.

2-ter. All'articolo 2-bis, comma 2, del decreto legislativo 14 marzo 2013, n. 33, la lettera b) e' sostituita dalla seguente: "b) alle societa' in controllo pubblico come definite dall'articolo 2, comma 1, lettera m), del decreto legislativo 19 agosto 2016, n. 175. Sono escluse le societa' quotate come definite dall'articolo 2, comma 1, lettera p), dello stesso decreto legislativo, nonche' le societa' da esse partecipate, salvo che queste ultime siano, non per il tramite di societa' quotate, controllate o partecipate da amministrazioni pubbliche.".

))

## Art. 28. - Abrogazioni

1. Sono abrogati:

- a) gli articoli 116, 122 del decreto legislativo 18 agosto 2000, n. 267;
- b) l'articolo 14, comma 1, del decreto legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326;
- c) l'articolo 1, comma 3, lettera n), della legge 23 agosto 2004, n. 239;
- d) l'articolo 13 del decreto legge 4 luglio 2006, n. 223, convertito, con modificazioni, dalla legge 4 agosto 2006, n. 248;
- e) l'articolo 1, commi 725, 726, 727, 728, 729, 730, 733 e 735 della legge 27 dicembre 2006, n. 296;
- f) l'articolo 3, commi 12, 12-bis, 14, 15, 16, 17, 27, 27-bis, 28, 28-bis, 29, 32-bis, 32-ter e 44, ottavo periodo, della legge 24 dicembre 2007, n. 244;
- g) l'articolo 18 del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, commi 1, 2 e 3;
- h) l'articolo 71 della legge 18 giugno 2009, n. 69; l) l'articolo 6, comma 19, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122; m) l'articolo 3-bis, comma 6, del decreto-legge 13 agosto 2011, n. 138, convertito, con modificazioni, dalla legge 14 settembre 2011, n. 148; n) l'articolo 23-bis, commi 5-bis, 5-ter, 5-quater, 5-quinquies e 5-sexies, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214; o) l'articolo 4, comma 4, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, limitatamente al primo e al terzo periodo; p) l'articolo 4, comma 5, del citato decreto-legge n. 95 del 2012, limitatamente al primo periodo e alle parole "e dal terzo" del secondo periodo; q) l'articolo 4, comma 13, del citato decreto-legge n. 95 del 2012, limitatamente al primo, al secondo e al quarto periodo; r) l'articolo 3, comma 7-bis, del decreto-legge 31 agosto 2013, n. 101, convertito in legge 30 ottobre 2013, n. 125; s) l'articolo 1, commi 551, limitatamente al secondo periodo, 558 e 562, limitatamente alla lettera b), della legge 27 dicembre 2013, n. 147; t) l'articolo 1, commi da 563 a 568 e da 568-ter a 569-bis, della legge 27 dicembre 2013, n. 147; u) l'articolo 23 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89; v) l'articolo 1, comma 672, della legge 28 dicembre 2015, n. 208.

